@@ -26,6 +26,9 @@ private:
 private slots:
     void saveExercise();
 
+signals:
+    void closed();
+
 };
 
 #endif // NEWEXERCISE_H
