@@ -27,6 +27,9 @@ private:
 private slots:
     void saveExercise();
 
+signals:
+    void closed();
+
 };
 
 #endif // NEWPROGRAM_H
