@@ -6,6 +6,11 @@ Program::Program(QString n, QList<Exercise> e)
     exercises = e;
 }
 
+QString Program::getName()
+{
+    return name;
+}
+
 QStringList Program::getExerciseNames()
 {
     QStringList list;
